# Example

Here are some examples that can help you use Python binding of [Tonbo](https://github.com/tonbo-io/tonbo)

### Declaration

- The [record.py](record.py) file shows how to define a `Tonbo` record
- The [write_batch.py](write_batch.py) file shows how to insert records in batch
- The [transaction.py](transaction.py) file shows how to use transaction
- The [declare.py](declare.py) file shows how to use `Tonbo` for simple data operations.
- The [multiple_instance.py](multiple_instance.py) file shows how to combine different `Tonbo` record with `TonboDB`s.

### Fusion storage

The [fusion_storage.py](fusion_storage.py) file shows how to store data across different storage.
